#!/bin/sh
#
# Functions for finding and loading extensions.
#
# Copyright 2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

# The list of defined extensions, one per line, each line tab-separated,
# containing ACTION, MIN-ARGS, MAX-ARGS, DESCRIPTION, and DATA-TYPE.
#
extensionList=""

# Define a new action whose name is $1, minimum argument count is $2,
# maximum argument count is $3, description is $4, and data type is $5.
#
uactRegisterExtension () {
	uactDebug "registering extension: action \"$1\", min args \"$2\", max args \"$3\", description \"$4\", data type \"$5\""
	extensionList="$(printf "%s\n%s\t%s\t%s\t%s\t%s\n" "${extensionList}" "$1" "$2" "$3" "$4" "$5" | sed '/^$/d')"
}

# Load all extension scripts, if they haven't already been loaded.
#
uactLoadExtensions () {
	test -n "${extensionList}" && return
	eligibleExtensionScripts="$(find "${EXTENSIONDIR}" -type f -name "*.sh" -maxdepth 1 2>/dev/null | grep -Fv ' ' | sort)"
	for extensionScript in ${eligibleExtensionScripts}; do
		uactDebug "loading extension script: ${extensionScript}"
		. "${extensionScript}"
	done
}
