#!/bin/sh
#
# Code common to all service actions.
#
# Copyright 2023-2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

serviceManagerType=""
serviceManagerVariant=""

# Set the "serviceManagerType" variable to the function prefix for the
# service manager that is in use on this system, and "serviceManagerVariant"
# to the variant if applicable, such as "redhat" vs "debian" for the
# "sysvinit" type, or report an error if no supported service manager was
# found (and return 2).
#
uactIdentifyServiceManager () {
	if command -v systemctl >/dev/null 2>&1; then
		serviceManagerType="systemd"
		serviceManagerVariant=""
	elif command -v service >/dev/null 2>&1 && command -v update-rc.d >/dev/null 2>&1; then
		serviceManagerType="sysvinit"
		serviceManagerVariant="debian"
	elif command -v service >/dev/null 2>&1 && command -v chkconfig >/dev/null 2>&1; then
		serviceManagerType="sysvinit"
		serviceManagerVariant="redhat"
	elif command -v service >/dev/null 2>&1 && command -v sysrc >/dev/null 2>&1; then
		serviceManagerType="freebsd"
		serviceManagerVariant=""
	elif command -v rcctl >/dev/null 2>&1; then
		serviceManagerType="openbsd"
		serviceManagerVariant=""
	elif command -v rc-status >/dev/null 2>&1 && command -v rc-update >/dev/null 2>&1; then
		serviceManagerType="openrc"
		serviceManagerVariant=""
	else
		uactError "NO-SERVICE-MANAGER"
		return 2
	fi
	uactDebug "serviceManagerType=[${serviceManagerType}], serviceManagerVariant=[${serviceManagerVariant}]"
	return 0
}


uactService () {
	uactIdentifyServiceManager
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	# Load the appropriate overrides for the service type.
	uactOverrideClass "${serviceManagerType}" "$@"
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	return 0
}
