# Notes for developers and translators

## Scripting notes

All scripts are written for the POSIX shell (`/bin/sh`), with no extensions,
for maximum portability.  The "`shellcheck`" utility should be used on each
component to highlight any inconsistencies.

The main entry point is _src/cli.sh_.  The script that is installed by
"`make install`" is a concatenation of _settings.sh_ (derived from
_settings.sh.in_ by the _configure_ script) and _src/cli.sh_.

Each component should not output any progress or error information directly,
unless it comes straight from the underlying utility it's acting as a
wrapper for.  Instead, call the **uactInfo** function for informational
messages, **uactDebug** for debugging messages, and **uactError** to report
an error; those functions take care of checking the command-line arguments
and adding the appropriate prefixes.  See _src/output.sh_ for these
functions, and note that **uactError** expects a standardised argument, not
an arbitrary string - this is so that human-readable error messages are all
defined in one place and can be translated more easily in future.

Components should not use hard-coded paths; refer to variables defined in
_settings.sh_ instead.

Whenever a command needs to be run to gather information or perform an
action, prefix it with **uactRun** so that the appropriate informational
messages are generated automatically.  Don't use **uactRun** in the middle
of pipelines that are processing the output of something else - for example
it's not generally needed before "`awk`" or "`sed`".

Functions to perform the actions for particular system types are defined via
overrides.  For example, for all of the actions starting with **package-**,
the **uactPackage** function in _src/package.sh_ is called first, which then
determines which package manager is in use; that gives the prefix for the
next parts, so for the Debian package manager, _src/debian-package.sh_ is
loaded, which defines functions such as **uactDebianPackageInstall** for the
**package-install** action.  See _src/override.sh_ for details.

Bear in mind that the action function is run in a subshell, so any changes
it makes to environment variables will not persist after it returns.


## Translation notes

There are no notes for translators yet, as internationalisation attempts
have not yet begun.  Please contact the author if you wish to assist.


## Release checklist

The package maintainer should run through these steps for a new release:

 * Version bump and documentation checks:
   * Update the version in _configure.ac_ and _docs/NEWS.md_
   * Check that _docs/NEWS.md_ is up to date
   * Check that the manual _docs/uact.8_ is up to date
   * Check that the copyright year in _src/version.sh_ is up to date
   * Run "`make docs/uact.8.md`" and, if using VPATH, copy the result to the source directory
 * Ensure everything has been committed to the repository
 * Run "`autoreconf`" in the source directory
 * Consistency and build checks:
   * Wipe the build directory, and run "`configure`" there
   * Run "`make distcheck`"
   * Run "`./configure && make check`", using the _tar.gz_ that was just created
 * Run "`make release MAINTAINER=(signing-user)`"
 * Update the project web site:
   * Copy the release _.tar.gz_, _.txt_, and _.asc_ files to the web site
   * Run "`make docs/uact.8.html docs/NEWS.html`" and copy the results to the web site
   * Update the version numbers on the web site
   * Update the package index on the web site
 * Create a new release in the repository, and apply the associated tag

